import { NCPAuthKeyType, SMSserviceAuthType } from "../../types/auth_types";
import { SendSMSParamType } from "../../types/param_types";
import { ApiClientResponse, SendSMSReturnType, SearchMessageRequestReturnType, SearchMessageResultReturnType } from "../../types/return_types";
export declare class SMS {
    /**
     * The ApiClient for working with http request
     *
     * @access private
     * @type {ApiClient}
     * @memberof SMS
     */
    private client;
    /**
     * The account access Key for API authentication
     *
     * @access private
     * @type {NCPAuthKeyType}
     * @memberof SMS
     */
    private ncpAuthKey;
    /**
     * The phoneNumber, serviceId for using SMS API
     *
     * @access private
     * @type {SMSserviceAuthType}
     * @memberof SMS
     */
    private smsAuth;
    /**
     * Creates an instance of SMS service agent.
     *
     * @param {string} baseURL The baseURL of each session ( based on service )
     * @param {NCPAuthKeyType} ncpAuthKey NCP API authentication data for using API
     * @param {SMSserviceAuthType} smsAuth Service identification for using SMS Service
     * @memberof SMS
     */
    constructor(baseUrl: string, ncpAuthKey: NCPAuthKeyType, smsAuth: SMSserviceAuthType);
    /**
     * Construct SendSMS Service apiRequest. Generate signature for signing, pass SendSMSParams to body.
     * Single / Multiple send mode supported.
     * @async
     * @access public
     * @param {(SendSMSParamType | SendSMSParamType[])} apiRequest - Message-reference Data with ( to, content ). Single / Multi value passing supported.
     * @param {(number | undefined)} countryCode - CountryCode for recipient. ( default : 82 )
     * @returns {Promise<ApiClientResponse<SendSMSReturnType>>} return Promise response of http request with current ApiRequest configs and handle errors
     * @memberof SMS
     */
    sendSMS(smsParam: SendSMSParamType | SendSMSParamType[], countryCode?: number): Promise<ApiClientResponse<SendSMSReturnType>>;
    /**
     * Construct searchMessageRequest Service apiRequest. Generate signature for signing, pass requestId for search.
     * return the requestData for given requestId. It also returns messages info refer to the request.
     * @async
     * @access public
     * @param {string} requestId - requestId which get from response of sendSMS API
     * @returns {Promise<ApiClientResponse<SearchMessageRequestReturnType>>} return Promise response of http request with current ApiRequest configs and handle errors
     * @memberof SMS
     */
    searchMessageRequest(requestId: string): Promise<ApiClientResponse<SearchMessageRequestReturnType>>;
    /**
     * Construct searchMessageResult Service apiRequest. Generate signature for signing, pass requestId for search.
     * return the requestData for given messageId. It also returns messages info refer to the message.
     * It's response data is more detail than searchMessageResult with completeTime, statuses, telcoCode, etc.
     * @async
     * @access public
     * @param {string} messageId - messageId which get from response of searchMessageRequest API
     * @returns {Promise<ApiClientResponse<SearchMessageRequestReturnType>>} return Promise response of http request with current ApiRequest configs and handle errors
     * @memberof SMS
     */
    searchMessageResult(messageId: string): Promise<ApiClientResponse<SearchMessageResultReturnType>>;
}
