"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServiceError = exports.ApiError = exports.ApiErrorEnum = void 0;
/**
 * Enum for API Error represented.
 * Covering from client's error or validation to error for server response
 * @readonly
 * @enum {string} Error Messages
 */
var ApiErrorEnum;
(function (ApiErrorEnum) {
    ApiErrorEnum["invalidURL"] = "Invalid URL";
    ApiErrorEnum["httpStatusCode"] = "Unexpected HTTP Status Code :";
    ApiErrorEnum["unexpectedResponse"] = "Unexpected response from the server";
    ApiErrorEnum["noResponseFromServer"] = "No response from the server";
    ApiErrorEnum["requestConfigurationError"] = "Error occured during setup request";
})(ApiErrorEnum = exports.ApiErrorEnum || (exports.ApiErrorEnum = {}));
class ApiError extends Error {
    constructor(error, httpCode) {
        httpCode === undefined ? super(error) : super(`${error} ${httpCode}`);
        Object.setPrototypeOf(this, ApiError.prototype);
    }
}
exports.ApiError = ApiError;
class ServiceError extends Error {
    constructor(errorMessage) {
        super(errorMessage);
        Object.setPrototypeOf(this, ApiError.prototype);
    }
}
exports.ServiceError = ServiceError;
/**
 * Enum for Errors by http status code which provided by NCP SENS API
 * @readonly
 * @enum {number} Http Status Code
 */
var SENS_Error;
(function (SENS_Error) {
    SENS_Error[SENS_Error["badRequest"] = 400] = "badRequest";
    SENS_Error[SENS_Error["unauthorized"] = 401] = "unauthorized";
    SENS_Error[SENS_Error["forbidden"] = 403] = "forbidden";
    SENS_Error[SENS_Error["notFound"] = 404] = "notFound";
    SENS_Error[SENS_Error["tooManyRequests"] = 429] = "tooManyRequests";
    SENS_Error[SENS_Error["internalServerError"] = 500] = "internalServerError";
})(SENS_Error || (SENS_Error = {}));
/**
* Enum for Errors by http status code which provided by NCP PAPAGO API
* @readonly
* @enum {number} Http Status Code
*/
var PAPAGO_Error;
(function (PAPAGO_Error) {
    PAPAGO_Error[PAPAGO_Error["badRequest"] = 400] = "badRequest";
    PAPAGO_Error[PAPAGO_Error["unauthorized"] = 401] = "unauthorized";
    PAPAGO_Error[PAPAGO_Error["forbidden"] = 403] = "forbidden";
    PAPAGO_Error[PAPAGO_Error["notFound"] = 404] = "notFound";
    PAPAGO_Error[PAPAGO_Error["tooManyRequests"] = 429] = "tooManyRequests";
    PAPAGO_Error[PAPAGO_Error["internalServerError"] = 500] = "internalServerError";
})(PAPAGO_Error || (PAPAGO_Error = {}));
